/*******************************************************************************
* File Name: Counter_RPM_PM.c  
* Version 3.0
*
*  Description:
*    This file provides the power management source code to API for the
*    Counter.  
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Counter_RPM.h"

static Counter_RPM_backupStruct Counter_RPM_backup;


/*******************************************************************************
* Function Name: Counter_RPM_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Counter_RPM_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void Counter_RPM_SaveConfig(void) 
{
    #if (!Counter_RPM_UsingFixedFunction)

        Counter_RPM_backup.CounterUdb = Counter_RPM_ReadCounter();

        #if(!Counter_RPM_ControlRegRemoved)
            Counter_RPM_backup.CounterControlRegister = Counter_RPM_ReadControlRegister();
        #endif /* (!Counter_RPM_ControlRegRemoved) */

    #endif /* (!Counter_RPM_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Counter_RPM_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Counter_RPM_backup:  Variables of this global structure are used to 
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void Counter_RPM_RestoreConfig(void) 
{      
    #if (!Counter_RPM_UsingFixedFunction)

       Counter_RPM_WriteCounter(Counter_RPM_backup.CounterUdb);

        #if(!Counter_RPM_ControlRegRemoved)
            Counter_RPM_WriteControlRegister(Counter_RPM_backup.CounterControlRegister);
        #endif /* (!Counter_RPM_ControlRegRemoved) */

    #endif /* (!Counter_RPM_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Counter_RPM_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Counter_RPM_backup.enableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void Counter_RPM_Sleep(void) 
{
    #if(!Counter_RPM_ControlRegRemoved)
        /* Save Counter's enable state */
        if(Counter_RPM_CTRL_ENABLE == (Counter_RPM_CONTROL & Counter_RPM_CTRL_ENABLE))
        {
            /* Counter is enabled */
            Counter_RPM_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            Counter_RPM_backup.CounterEnableState = 0u;
        }
    #else
        Counter_RPM_backup.CounterEnableState = 1u;
        if(Counter_RPM_backup.CounterEnableState != 0u)
        {
            Counter_RPM_backup.CounterEnableState = 0u;
        }
    #endif /* (!Counter_RPM_ControlRegRemoved) */
    
    Counter_RPM_Stop();
    Counter_RPM_SaveConfig();
}


/*******************************************************************************
* Function Name: Counter_RPM_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Counter_RPM_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Counter_RPM_Wakeup(void) 
{
    Counter_RPM_RestoreConfig();
    #if(!Counter_RPM_ControlRegRemoved)
        if(Counter_RPM_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            Counter_RPM_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif /* (!Counter_RPM_ControlRegRemoved) */
    
}


/* [] END OF FILE */
